@@ -13,20 +13,17 @@ from .ckplayer import *
 from .cntv import *
 from .coub import *
 from .dailymotion import *
-from .dilidili import *
 from .douban import *
 from .douyin import *
 from .douyutv import *
 from .ehow import *
 from .facebook import *
-from .fantasy import *
 from .fc2video import *
 from .flickr import *
 from .freesound import *
 from .funshion import *
 from .google import *
 from .heavymusic import *
-from .huaban import *
 from .icourses import *
 from .ifeng import *
 from .imgur import *
