@@ -8,32 +8,64 @@ from xml.dom.minidom import parseString
 class YouTube(VideoExtractor):
     name = "YouTube"
 
-    # YouTube media encoding options, in descending quality order.
+    # Non-DASH YouTube media encoding options, in descending quality order.
     # http://en.wikipedia.org/wiki/YouTube#Quality_and_codecs. Retrieved July 17, 2014.
     stream_types = [
-        {'itag': '38', 'container': 'MP4', 'video_resolution': '3072p', 'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '3.5-5', 'audio_encoding': 'AAC', 'audio_bitrate': '192'},
+        {'itag': '38', 'container': 'MP4', 'video_resolution': '3072p',
+         'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '3.5-5',
+         'audio_encoding': 'AAC', 'audio_bitrate': '192'},
         #{'itag': '85', 'container': 'MP4', 'video_resolution': '1080p', 'video_encoding': 'H.264', 'video_profile': '3D', 'video_bitrate': '3-4', 'audio_encoding': 'AAC', 'audio_bitrate': '192'},
-        {'itag': '46', 'container': 'WebM', 'video_resolution': '1080p', 'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '', 'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
-        {'itag': '37', 'container': 'MP4', 'video_resolution': '1080p', 'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '3-4.3', 'audio_encoding': 'AAC', 'audio_bitrate': '192'},
+        {'itag': '46', 'container': 'WebM', 'video_resolution': '1080p',
+         'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '',
+         'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
+        {'itag': '37', 'container': 'MP4', 'video_resolution': '1080p',
+         'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '3-4.3',
+         'audio_encoding': 'AAC', 'audio_bitrate': '192'},
         #{'itag': '102', 'container': 'WebM', 'video_resolution': '720p', 'video_encoding': 'VP8', 'video_profile': '3D', 'video_bitrate': '', 'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
-        {'itag': '45', 'container': 'WebM', 'video_resolution': '720p', 'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '2', 'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
+        {'itag': '45', 'container': 'WebM', 'video_resolution': '720p',
+         'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '2',
+         'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
         #{'itag': '84', 'container': 'MP4', 'video_resolution': '720p', 'video_encoding': 'H.264', 'video_profile': '3D', 'video_bitrate': '2-3', 'audio_encoding': 'AAC', 'audio_bitrate': '192'},
-        {'itag': '22', 'container': 'MP4', 'video_resolution': '720p', 'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '2-3', 'audio_encoding': 'AAC', 'audio_bitrate': '192'},
-        {'itag': '120', 'container': 'FLV', 'video_resolution': '720p', 'video_encoding': 'H.264', 'video_profile': 'Main@L3.1', 'video_bitrate': '2', 'audio_encoding': 'AAC', 'audio_bitrate': '128'}, # Live streaming only
-        {'itag': '44', 'container': 'WebM', 'video_resolution': '480p', 'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '1', 'audio_encoding': 'Vorbis', 'audio_bitrate': '128'},
-        {'itag': '35', 'container': 'FLV', 'video_resolution': '480p', 'video_encoding': 'H.264', 'video_profile': 'Main', 'video_bitrate': '0.8-1', 'audio_encoding': 'AAC', 'audio_bitrate': '128'},
+        {'itag': '22', 'container': 'MP4', 'video_resolution': '720p',
+         'video_encoding': 'H.264', 'video_profile': 'High', 'video_bitrate': '2-3',
+         'audio_encoding': 'AAC', 'audio_bitrate': '192'},
+        {'itag': '120', 'container': 'FLV', 'video_resolution': '720p',
+         'video_encoding': 'H.264', 'video_profile': 'Main@L3.1', 'video_bitrate': '2',
+         'audio_encoding': 'AAC', 'audio_bitrate': '128'}, # Live streaming only
+        {'itag': '44', 'container': 'WebM', 'video_resolution': '480p',
+         'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '1',
+         'audio_encoding': 'Vorbis', 'audio_bitrate': '128'},
+        {'itag': '35', 'container': 'FLV', 'video_resolution': '480p',
+         'video_encoding': 'H.264', 'video_profile': 'Main', 'video_bitrate': '0.8-1',
+         'audio_encoding': 'AAC', 'audio_bitrate': '128'},
         #{'itag': '101', 'container': 'WebM', 'video_resolution': '360p', 'video_encoding': 'VP8', 'video_profile': '3D', 'video_bitrate': '', 'audio_encoding': 'Vorbis', 'audio_bitrate': '192'},
         #{'itag': '100', 'container': 'WebM', 'video_resolution': '360p', 'video_encoding': 'VP8', 'video_profile': '3D', 'video_bitrate': '', 'audio_encoding': 'Vorbis', 'audio_bitrate': '128'},
-        {'itag': '43', 'container': 'WebM', 'video_resolution': '360p', 'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '0.5', 'audio_encoding': 'Vorbis', 'audio_bitrate': '128'},
-        {'itag': '34', 'container': 'FLV', 'video_resolution': '360p', 'video_encoding': 'H.264', 'video_profile': 'Main', 'video_bitrate': '0.5', 'audio_encoding': 'AAC', 'audio_bitrate': '128'},
+        {'itag': '43', 'container': 'WebM', 'video_resolution': '360p',
+         'video_encoding': 'VP8', 'video_profile': '', 'video_bitrate': '0.5',
+         'audio_encoding': 'Vorbis', 'audio_bitrate': '128'},
+        {'itag': '34', 'container': 'FLV', 'video_resolution': '360p',
+         'video_encoding': 'H.264', 'video_profile': 'Main', 'video_bitrate': '0.5',
+         'audio_encoding': 'AAC', 'audio_bitrate': '128'},
         #{'itag': '82', 'container': 'MP4', 'video_resolution': '360p', 'video_encoding': 'H.264', 'video_profile': '3D', 'video_bitrate': '0.5', 'audio_encoding': 'AAC', 'audio_bitrate': '96'},
-        {'itag': '18', 'container': 'MP4', 'video_resolution': '270p/360p', 'video_encoding': 'H.264', 'video_profile': 'Baseline', 'video_bitrate': '0.5', 'audio_encoding': 'AAC', 'audio_bitrate': '96'},
-        {'itag': '6', 'container': 'FLV', 'video_resolution': '270p', 'video_encoding': 'Sorenson H.263', 'video_profile': '', 'video_bitrate': '0.8', 'audio_encoding': 'MP3', 'audio_bitrate': '64'},
+        {'itag': '18', 'container': 'MP4', 'video_resolution': '360p',
+         'video_encoding': 'H.264', 'video_profile': 'Baseline', 'video_bitrate': '0.5',
+         'audio_encoding': 'AAC', 'audio_bitrate': '96'},
+        {'itag': '6', 'container': 'FLV', 'video_resolution': '270p',
+         'video_encoding': 'Sorenson H.263', 'video_profile': '', 'video_bitrate': '0.8',
+         'audio_encoding': 'MP3', 'audio_bitrate': '64'},
         #{'itag': '83', 'container': 'MP4', 'video_resolution': '240p', 'video_encoding': 'H.264', 'video_profile': '3D', 'video_bitrate': '0.5', 'audio_encoding': 'AAC', 'audio_bitrate': '96'},
-        {'itag': '13', 'container': '3GP', 'video_resolution': '', 'video_encoding': 'MPEG-4 Visual', 'video_profile': '', 'video_bitrate': '0.5', 'audio_encoding': 'AAC', 'audio_bitrate': ''},
-        {'itag': '5', 'container': 'FLV', 'video_resolution': '240p', 'video_encoding': 'Sorenson H.263', 'video_profile': '', 'video_bitrate': '0.25', 'audio_encoding': 'MP3', 'audio_bitrate': '64'},
-        {'itag': '36', 'container': '3GP', 'video_resolution': '240p', 'video_encoding': 'MPEG-4 Visual', 'video_profile': 'Simple', 'video_bitrate': '0.175', 'audio_encoding': 'AAC', 'audio_bitrate': '36'},
-        {'itag': '17', 'container': '3GP', 'video_resolution': '144p', 'video_encoding': 'MPEG-4 Visual', 'video_profile': 'Simple', 'video_bitrate': '0.05', 'audio_encoding': 'AAC', 'audio_bitrate': '24'},
+        {'itag': '13', 'container': '3GP', 'video_resolution': '',
+         'video_encoding': 'MPEG-4 Visual', 'video_profile': '', 'video_bitrate': '0.5',
+         'audio_encoding': 'AAC', 'audio_bitrate': ''},
+        {'itag': '5', 'container': 'FLV', 'video_resolution': '240p',
+         'video_encoding': 'Sorenson H.263', 'video_profile': '', 'video_bitrate': '0.25',
+         'audio_encoding': 'MP3', 'audio_bitrate': '64'},
+        {'itag': '36', 'container': '3GP', 'video_resolution': '240p',
+         'video_encoding': 'MPEG-4 Visual', 'video_profile': 'Simple', 'video_bitrate': '0.175',
+         'audio_encoding': 'AAC', 'audio_bitrate': '32'},
+        {'itag': '17', 'container': '3GP', 'video_resolution': '144p',
+         'video_encoding': 'MPEG-4 Visual', 'video_profile': 'Simple', 'video_bitrate': '0.05',
+         'audio_encoding': 'AAC', 'audio_bitrate': '24'},
     ]
 
     def decipher(js, s):
@@ -195,13 +227,29 @@ class YouTube(VideoExtractor):
 
         elif video_info['status'] == ['fail']:
             if video_info['errorcode'] == ['150']:
-                video_page = get_content('https://www.youtube.com/watch?v=%s' % self.vid)
+                if cookies:
+                    # Load necessary cookies into headers (for age-restricted videos)
+                    consent, ssid, hsid, sid = 'YES', '', '', ''
+                    for cookie in cookies:
+                        if cookie.domain.endswith('.youtube.com'):
+                            if cookie.name == 'SSID':
+                                ssid = cookie.value
+                            elif cookie.name == 'HSID':
+                                hsid = cookie.value
+                            elif cookie.name == 'SID':
+                                sid = cookie.value
+                    cookie_str = 'CONSENT=%s; SSID=%s; HSID=%s; SID=%s' % (consent, ssid, hsid, sid)
+
+                    video_page = get_content('https://www.youtube.com/watch?v=%s' % self.vid,
+                                             headers={'Cookie': cookie_str})
+                else:
+                    video_page = get_content('https://www.youtube.com/watch?v=%s' % self.vid)
+
                 try:
                     ytplayer_config = json.loads(re.search('ytplayer.config\s*=\s*([^\n]+});ytplayer', video_page).group(1))
                 except:
                     msg = re.search('class="message">([^<]+)<', video_page).group(1)
-                    log.wtf('[Failed] "%s"' % msg.strip(), exit_code=None)
-                    raise
+                    log.wtf('[Failed] Got message "%s". Try to login with --cookies.' % msg.strip())
 
                 if 'title' in ytplayer_config['args']:
                     # 150 Restricted from playback on certain sites
@@ -389,7 +437,7 @@ class YouTube(VideoExtractor):
                             dash_urls = self.__class__.chunk_by_range(dash_url, int(dash_size))
                             dash_mp4_a_urls = self.__class__.chunk_by_range(dash_mp4_a_url, int(dash_mp4_a_size))
                             self.dash_streams[itag] = {
-                                'quality': stream['size'],
+                                'quality': '%s (%s)' % (stream['size'], stream['quality_label']),
                                 'itag': itag,
                                 'type': mimeType,
                                 'mime': mimeType,
@@ -416,7 +464,7 @@ class YouTube(VideoExtractor):
                             dash_urls = self.__class__.chunk_by_range(dash_url, int(dash_size))
                             audio_urls = self.__class__.chunk_by_range(audio_url, int(audio_size))
                             self.dash_streams[itag] = {
-                                'quality': stream['size'],
+                                'quality': '%s (%s)' % (stream['size'], stream['quality_label']),
                                 'itag': itag,
                                 'type': mimeType,
                                 'mime': mimeType,
